# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-11-20 12:04
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_countries.fields


class Migration(migrations.Migration):

    dependencies = [
        ('leprikon', '0015_protect_leader'),
    ]

    operations = []
    for model_name in ['participant', 'clubregistration', 'eventregistration']:
        operations += [
            migrations.AlterField(
                model_name=model_name,
                name='citizenship',
                field=django_countries.fields.CountryField(max_length=2, verbose_name='citizenship'),
            ),
        ]
