# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2017-01-28 00:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import filer.fields.file


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0006_auto_20160623_1627'),
        ('leprikon', '0025_club_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='PrintSetup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150, verbose_name='name')),
                ('top', models.IntegerField(blank=True, default=20, verbose_name='margin top')),
                ('left', models.IntegerField(blank=True, default=20, verbose_name='margin left')),
                ('right', models.IntegerField(blank=True, default=20, verbose_name='margin right')),
                ('bottom', models.IntegerField(blank=True, default=20, verbose_name='margin bottom')),
                ('template', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='filer.File', verbose_name='pdf template')),
            ],
            options={
                'ordering': ('name',),
                'verbose_name': 'print setup',
                'verbose_name_plural': 'print setups',
            },
        ),
        migrations.AddField(
            model_name='club',
            name='reg_printsetup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='leprikon.PrintSetup', verbose_name='registration print setup'),
        ),
        migrations.AddField(
            model_name='clubtype',
            name='reg_printsetup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='leprikon.PrintSetup', verbose_name='registration print setup'),
        ),
        migrations.AddField(
            model_name='event',
            name='reg_printsetup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='leprikon.PrintSetup', verbose_name='registration print setup'),
        ),
        migrations.AddField(
            model_name='eventtype',
            name='reg_printsetup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='leprikon.PrintSetup', verbose_name='registration print setup'),
        ),
    ]
