# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-01-16 13:51
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('leprikon', '0008_leprikonsite_company_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='subjectpayment',
            name='received_by',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='received by'),
        ),
    ]
