# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-10-27 16:17
from __future__ import unicode_literals

from django.db import migrations
import leprikon.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('leprikon', '0012_place_on_delete_set_null'),
    ]

    operations = [
        migrations.AlterField(
            model_name='participant',
            name='birth_num',
            field=leprikon.models.fields.BirthNumberField(verbose_name='birth number'),
        ),
        migrations.AlterUniqueTogether(
            name='participant',
            unique_together=set([('user', 'birth_num')]),
        ),
    ]
