# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-08-29 16:34
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leprikon', '0017_citizenship'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='subjectregistration',
            name='participant_citizenship_old',
        ),
        migrations.RemoveField(
            model_name='participant',
            name='citizenship_old',
        ),
    ]
