# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-09-06 15:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leprikon', '0011_registration_requests'),
    ]

    operations = [
        migrations.AlterField(
            model_name='club',
            name='place',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='clubs', to='leprikon.Place', verbose_name='place'),
        ),
        migrations.AlterField(
            model_name='event',
            name='place',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='events', to='leprikon.Place', verbose_name='place'),
        ),
    ]
